# -*- coding: utf-8 -*-
# This file is part of the sale-point-invoice-module for Tryton from m-ds.de.
# The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

from trytond.model import ModelSQL, fields
from trytond.pool import PoolMeta, Pool
from trytond.modules.company.model import CompanyValueMixin
from .invoice import sel_modegross


modegross = fields.Selection(
    string='Calculation method',
    selection=sel_modegross,
    help='Default setting for calculation method in invoices, ' +
    'sales and purchases.')


class Configuration(metaclass=PoolMeta):
    __name__ = 'account.configuration'

    modegross = fields.MultiValue(modegross)

    @classmethod
    def multivalue_model(cls, field):
        pool = Pool()
        if field in 'modegross':
            return pool.get('account.configuration.default_grossmode')
        return super(Configuration, cls).multivalue_model(field)

    @classmethod
    def default_modegross(cls, **pattern):
        return cls.multivalue_model('modegross').default_modegross()

# end Configuration


class ConfigurationDefaultGrossmode(ModelSQL, CompanyValueMixin):
    "Account Configuration Default Gross-Mode"
    __name__ = 'account.configuration.default_grossmode'

    modegross = modegross

    @classmethod
    def default_modegross(cls):
        return 'net'

# end ConfigurationDefaultGrossmode
