# -*- coding: utf-8 -*-
# This file is part of the sale-point-invoice-module for Tryton from m-ds.de.
# The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.

from trytond.pool import PoolMeta
from trytond.model import fields
from trytond.modules.product import price_digits
from trytond.pool import Pool
from trytond.transaction import Transaction


class ProductTemplate(metaclass=PoolMeta):
    __name__ = 'product.template'

    used_gross_price = fields.Function(
        fields.Numeric(
            string='Used Gross Price',
            digits=price_digits,
            states={'invisible': True}),
        'on_change_with_used_gross_price')

    def on_change_with_used_gross_price(self, name=None):
        """ get gross-price
        """
        raise ValueError(
            'not implemented, function ' +
            '"on_change_with_used_gross_price" must be overwritten')

# end ProductTemplate


class ProductProduct(metaclass=PoolMeta):
    __name__ = 'product.product'

    def _get_sale_unit_gross_price(self, quantity=0):
        return self.template.used_gross_price

# ProductProduct


class SaleProductPriceList(metaclass=PoolMeta):
    __name__ = 'product.product'

    def _get_sale_unit_gross_price(self, quantity=0):
        """ compute gross-price in context of price-list
        """
        pool = Pool()
        PriceList = pool.get('product.price_list')
        Uom = pool.get('product.uom')
        User = pool.get('res.user')
        context = Transaction().context

        unit_gross_price = super()._get_sale_unit_gross_price(
            quantity=quantity)

        if context.get('price_list'):
            price_list = PriceList(context['price_list'])
            assert price_list.company == User(Transaction().user).company
            context_uom = None
            if context.get('uom'):
                context_uom = Uom(context['uom'])
            uom = context_uom or self.sale_uom
            if uom.category != self.sale_uom.category:
                uom = self.sale_uom
            new_price = price_list.compute(self, quantity, uom)
            if new_price is not None:
                unit_gross_price = new_price
        return unit_gross_price

# SaleProductPriceList


class ProductModGrossprice(metaclass=PoolMeta):
    __name__ = 'product.template'

    @fields.depends('gross_price')
    def on_change_with_used_gross_price(self, name=None):
        """ get gross-price from field 'gross_price' of module
            'product_grossprice' or 'sale_point'
        """
        return self.gross_price

# end ProductModGrossprice


class ProductModSalepoint(metaclass=PoolMeta):
    __name__ = 'product.template'

    @fields.depends('gross_price')
    def on_change_with_used_gross_price(self, name=None):
        """ get gross-price from field 'gross_price' of module
            'product_grossprice' or 'sale_point'
        """
        return self.gross_price

# end ProductModSalepoint
