# -*- coding: utf-8 -*-
# This file is part of the sale-point-invoice module from m-ds.de for
# Tryton.  The COPYRIGHT file at the top level of
# this repository contains the full copyright notices and license terms.


from trytond.pool import PoolMeta, Pool
from trytond.model import fields
from trytond.pyson import Eval, Bool
from .invoice import sel_modegross


class Subscription(metaclass=PoolMeta):
    __name__ = 'sale.subscription'

    modegross = fields.Selection(
        string='Invoice type', selection=sel_modegross, required=True,
        help='Calculate the invoice gross or net.',
        states={'readonly': Bool(Eval('lines'))}, depends=['lines'])

    @classmethod
    def default_modegross(cls):
        """ get setting from config
        """
        Configuration = Pool().get('account.configuration')

        cfg1 = Configuration.get_singleton()
        return getattr(cfg1, 'modegross', 'net')

    def _get_invoice(self):
        """ net/gross-mode of invoice
        """
        invoice = super(Subscription, self)._get_invoice()
        invoice.modegross = self.modegross
        return invoice

# end Subscription


class LineConsumption(metaclass=PoolMeta):
    __name__ = 'sale.subscription.line.consumption'

    @classmethod
    def get_invoice_lines(cls, consumptions, invoice):
        """ net/gross-mode
        """
        (lines, grouped_consumptions) = super(
            LineConsumption, cls).get_invoice_lines(consumptions, invoice)

        for line in lines:
            if line.origin and (invoice.modegross == 'gross'):
                if line.origin.__name__ == 'sale.subscription.line':
                    line.unit_gross_price = line.origin.unit_price
                    line.on_change_unit_gross_price()
        return lines, grouped_consumptions

#end LineConsumption
